Flask-Image-Resizer
===================

This is a fork of [mikeboers/Flask-Images](https://github.com/mikeboers/Flask-Images)

Flask-Image-Resizer is also a Flask extension that provides dynamic image resizing for your application.

## What was done
- Add svg minify options
- Fix compatibility issue with itsdangerous
- Update handle_request
- Add `_find_img`
- Add `get_aspect_ratio`
- Add `calculate_height`
